pub enum Error {
Info,
Input,
DeriveKeyPair,
Deserialization,
Batch,
ProofVerification,
Protocol,
Rng,
}Expand description
Represents an error in the manipulation of internal cryptographic data
Variants
Info
Size of info is longer then u16::MAX.
Input
Size of input is empty or longer then u16::MAX.
DeriveKeyPair
Size of info and seed together are longer then u16::MAX - 3.
Deserialization
Failure to deserialize bytes
Batch
Batched items are more then u16::MAX or length don’t match.
ProofVerification
In verifiable mode, occurs when the proof failed to verify
Protocol
The protocol has failed and can’t be completed.
Rng
Random number generator failure.