PoprfClient

Struct PoprfClient 

pub struct PoprfClient<CS: CipherSuite> { /* private fields */ }
A client which engages with a PoprfServer in verifiable mode, meaning that the OPRF outputs can be checked against a server public key.

Implementations

Source

impl<CS: CipherSuite> PoprfClient<CS>

pub fn blind<R: TryRng + TryCryptoRng>( input: &[u8], blinding_factor_rng: &mut R, ) -> Result<PoprfClientBlindResult<CS>>

Computes the first step for the multiplicative blinding version of DH-OPRF.

Errors
pub fn deterministic_blind_unchecked( input: &[u8], blind: <CS::Group as Group>::Scalar, ) -> Result<PoprfClientBlindResult<CS>>

Available on crate features danger only.

Computes the first step for the multiplicative blinding version of DH-OPRF, taking a blinding factor scalar as input instead of sampling from an RNG.

Caution

This should be used with caution, since it does not perform any checks on the validity of the blinding factor! In particular, a zero blind has no multiplicative inverse: a later finalize will then panic on prime-order curves and produce a degenerate (identity) output on Ristretto255. Only pass a blind known to be a non-zero scalar.

Errors

Error::Input if the input is empty or longer than u16::MAX.

pub fn finalize( &self, input: &[u8], evaluation_element: &EvaluationElement<CS>, proof: &Proof<CS>, pk: <CS::Group as Group>::Elem, info: Option<&[u8]>, ) -> Result<Output<CS::Hash>>

Computes the third step for the multiplicative blinding version of DH-OPRF, in which the client unblinds the server’s message.

Errors
pub fn batch_finalize<'a, II: 'a + Iterator<Item = &'a [u8]> + ExactSizeIterator, IC, IM>( inputs: II, clients: &'a IC, messages: &'a IM, proof: &Proof<CS>, pk: <CS::Group as Group>::Elem, info: Option<&'a [u8]>, ) -> Result<PoprfClientBatchFinalizeResult<'a, CS, II, IC, IM>>

Allows for batching of the finalization of multiple PoprfClient and EvaluationElement pairs

Errors

The resulting messages can each fail individually with Error::Input if the input is empty or longer than u16::MAX.

Source

impl<CS: CipherSuite> PoprfClient<CS>

pub fn serialize(&self) -> GenericArray<u8, PoprfClientLen<CS>>

Serialization into bytes

pub fn deserialize(input: &[u8]) -> Result<Self>

Deserialization from bytes

Errors

Error::Deserialization if failed to deserialize input.